#[non_exhaustive]pub struct AgenticRetrieveStreamInput {
pub messages: Option<Vec<AgenticRetrieveMessage>>,
pub retrievers: Option<Vec<AgenticRetriever>>,
pub agentic_retrieve_configuration: Option<AgenticRetrieveConfiguration>,
pub policy_configuration: Option<AgenticRetrievePolicyConfiguration>,
pub next_token: Option<String>,
pub user_context: Option<UserContext>,
pub generate_response: Option<bool>,
}Expand description
Request structure for the agentic retrieve stream operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.messages: Option<Vec<AgenticRetrieveMessage>>The list of messages for the agentic retrieval conversation.
retrievers: Option<Vec<AgenticRetriever>>The list of retrievers to use for agentic retrieval.
agentic_retrieve_configuration: Option<AgenticRetrieveConfiguration>Configuration settings for the agentic retrieval operation.
policy_configuration: Option<AgenticRetrievePolicyConfiguration>Policy configuration for guardrails and content filtering.
next_token: Option<String>Opaque continuation token for paginated results.
user_context: Option<UserContext>Contains information about the user making the request. This is used for access control filtering to ensure that retrieval results only include documents the user is authorized to access.
generate_response: Option<bool>Whether to generate a response based on the retrieved results.
Implementations
Sourceimpl AgenticRetrieveStreamInput
impl AgenticRetrieveStreamInput
Sourcepub fn messages(&self) -> &[AgenticRetrieveMessage]
pub fn messages(&self) -> &[AgenticRetrieveMessage]
The list of messages for the agentic retrieval conversation.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .messages.is_none().
Sourcepub fn retrievers(&self) -> &[AgenticRetriever]
pub fn retrievers(&self) -> &[AgenticRetriever]
The list of retrievers to use for agentic retrieval.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .retrievers.is_none().
Sourcepub fn agentic_retrieve_configuration(
&self,
) -> Option<&AgenticRetrieveConfiguration>
pub fn agentic_retrieve_configuration( &self, ) -> Option<&AgenticRetrieveConfiguration>
Configuration settings for the agentic retrieval operation.
Sourcepub fn policy_configuration(
&self,
) -> Option<&AgenticRetrievePolicyConfiguration>
pub fn policy_configuration( &self, ) -> Option<&AgenticRetrievePolicyConfiguration>
Policy configuration for guardrails and content filtering.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
Opaque continuation token for paginated results.
Sourcepub fn user_context(&self) -> Option<&UserContext>
pub fn user_context(&self) -> Option<&UserContext>
Contains information about the user making the request. This is used for access control filtering to ensure that retrieval results only include documents the user is authorized to access.
Sourcepub fn generate_response(&self) -> Option<bool>
pub fn generate_response(&self) -> Option<bool>
Whether to generate a response based on the retrieved results.
Sourceimpl AgenticRetrieveStreamInput
impl AgenticRetrieveStreamInput
Sourcepub fn builder() -> AgenticRetrieveStreamInputBuilder
pub fn builder() -> AgenticRetrieveStreamInputBuilder
Creates a new builder-style object to manufacture AgenticRetrieveStreamInput.