#[non_exhaustive]pub struct AgenticRetrieveStreamOutput {
pub stream: EventReceiver<AgenticRetrieveStreamResponseOutput, AgenticRetrieveStreamResponseOutputError>,
/* private fields */
}Expand description
Response structure for the agentic retrieve stream operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.stream: EventReceiver<AgenticRetrieveStreamResponseOutput, AgenticRetrieveStreamResponseOutputError>The output stream containing retrieval results and trace events.
Implementations
Sourceimpl AgenticRetrieveStreamOutput
impl AgenticRetrieveStreamOutput
Sourcepub fn stream(
&self,
) -> &EventReceiver<AgenticRetrieveStreamResponseOutput, AgenticRetrieveStreamResponseOutputError>
pub fn stream( &self, ) -> &EventReceiver<AgenticRetrieveStreamResponseOutput, AgenticRetrieveStreamResponseOutputError>
The output stream containing retrieval results and trace events.
Sourceimpl AgenticRetrieveStreamOutput
impl AgenticRetrieveStreamOutput
Sourcepub fn builder() -> AgenticRetrieveStreamOutputBuilder
pub fn builder() -> AgenticRetrieveStreamOutputBuilder
Creates a new builder-style object to manufacture AgenticRetrieveStreamOutput.