#[non_exhaustive]pub struct CheckIngestedDocumentAclOutputBuilder { /* private fields */ }Expand description
A builder for CheckIngestedDocumentAclOutput.
Implementations
Sourceimpl CheckIngestedDocumentAclOutputBuilder
impl CheckIngestedDocumentAclOutputBuilder
Sourcepub fn has_access(self, input: bool) -> Self
pub fn has_access(self, input: bool) -> Self
Specifies whether the user has access to the document based on the ingested access control list (ACL). Returns true if the user is allowed access, and false otherwise.
Sourcepub fn set_has_access(self, input: Option<bool>) -> Self
pub fn set_has_access(self, input: Option<bool>) -> Self
Specifies whether the user has access to the document based on the ingested access control list (ACL). Returns true if the user is allowed access, and false otherwise.
Sourcepub fn get_has_access(&self) -> &Option<bool>
pub fn get_has_access(&self) -> &Option<bool>
Specifies whether the user has access to the document based on the ingested access control list (ACL). Returns true if the user is allowed access, and false otherwise.
Sourcepub fn build(self) -> Result<CheckIngestedDocumentAclOutput, BuildError>
pub fn build(self) -> Result<CheckIngestedDocumentAclOutput, BuildError>
Consumes the builder and constructs a CheckIngestedDocumentAclOutput.
This method will fail if any of the following fields are not set: