#[non_exhaustive]pub struct CheckIngestedDocumentAclInput {
pub knowledge_base_id: Option<String>,
pub data_source_id: Option<String>,
pub document_id: Option<String>,
pub user_context: Option<UserContext>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.knowledge_base_id: Option<String>The unique identifier of the knowledge base that contains the document.
data_source_id: Option<String>The unique identifier of the data source that contains the document.
document_id: Option<String>The unique identifier of the document to check access for.
user_context: Option<UserContext>The context object containing identity information for access control filtering, including user ID and optional group memberships used to evaluate the document access control list (ACL).
Implementations
Sourceimpl CheckIngestedDocumentAclInput
impl CheckIngestedDocumentAclInput
Sourcepub fn knowledge_base_id(&self) -> Option<&str>
pub fn knowledge_base_id(&self) -> Option<&str>
The unique identifier of the knowledge base that contains the document.
Sourcepub fn data_source_id(&self) -> Option<&str>
pub fn data_source_id(&self) -> Option<&str>
The unique identifier of the data source that contains the document.
Sourcepub fn document_id(&self) -> Option<&str>
pub fn document_id(&self) -> Option<&str>
The unique identifier of the document to check access for.
Sourcepub fn user_context(&self) -> Option<&UserContext>
pub fn user_context(&self) -> Option<&UserContext>
The context object containing identity information for access control filtering, including user ID and optional group memberships used to evaluate the document access control list (ACL).
Sourceimpl CheckIngestedDocumentAclInput
impl CheckIngestedDocumentAclInput
Sourcepub fn builder() -> CheckIngestedDocumentAclInputBuilder
pub fn builder() -> CheckIngestedDocumentAclInputBuilder
Creates a new builder-style object to manufacture CheckIngestedDocumentAclInput.