#[non_exhaustive]pub struct GetDocumentContentInput {
pub knowledge_base_id: Option<String>,
pub data_source_id: Option<String>,
pub document_id: Option<String>,
pub output_format: Option<DocumentOutputFormat>,
pub user_context: Option<UserContext>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.knowledge_base_id: Option<String>The unique identifier of the knowledge base that contains the document.
data_source_id: Option<String>The unique identifier of the data source that contains the document.
document_id: Option<String>The unique identifier of the document to retrieve content for.
output_format: Option<DocumentOutputFormat>The output format for the document content. RAW returns the original file. EXTRACTED returns parsed text as JSON. Defaults to RAW.
user_context: Option<UserContext>Contains information about the user making the request. Use this to pass user identity information for access control filtering, so that retrieval results only include documents the user is authorized to access.
Implementations
Sourceimpl GetDocumentContentInput
impl GetDocumentContentInput
Sourcepub fn knowledge_base_id(&self) -> Option<&str>
pub fn knowledge_base_id(&self) -> Option<&str>
The unique identifier of the knowledge base that contains the document.
Sourcepub fn data_source_id(&self) -> Option<&str>
pub fn data_source_id(&self) -> Option<&str>
The unique identifier of the data source that contains the document.
Sourcepub fn document_id(&self) -> Option<&str>
pub fn document_id(&self) -> Option<&str>
The unique identifier of the document to retrieve content for.
Sourcepub fn output_format(&self) -> Option<&DocumentOutputFormat>
pub fn output_format(&self) -> Option<&DocumentOutputFormat>
The output format for the document content. RAW returns the original file. EXTRACTED returns parsed text as JSON. Defaults to RAW.
Sourcepub fn user_context(&self) -> Option<&UserContext>
pub fn user_context(&self) -> Option<&UserContext>
Contains information about the user making the request. Use this to pass user identity information for access control filtering, so that retrieval results only include documents the user is authorized to access.
Sourceimpl GetDocumentContentInput
impl GetDocumentContentInput
Sourcepub fn builder() -> GetDocumentContentInputBuilder
pub fn builder() -> GetDocumentContentInputBuilder
Creates a new builder-style object to manufacture GetDocumentContentInput.