#[non_exhaustive]pub struct GetDocumentContentOutput {
pub mime_type: String,
pub presigned_url: String,
pub document_content_length: Option<i64>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.mime_type: StringThe MIME type of the document content. For RAW format, this is the original file type (for example, application/pdf). For EXTRACTED format, this is always application/json.
presigned_url: StringA pre-signed URL for downloading the document content. The URL expires after 5 minutes.
document_content_length: Option<i64>The size of the document content in bytes available at the pre-signed URL.
Implementations
Sourceimpl GetDocumentContentOutput
impl GetDocumentContentOutput
Sourcepub fn mime_type(&self) -> &str
pub fn mime_type(&self) -> &str
The MIME type of the document content. For RAW format, this is the original file type (for example, application/pdf). For EXTRACTED format, this is always application/json.
Sourcepub fn presigned_url(&self) -> &str
pub fn presigned_url(&self) -> &str
A pre-signed URL for downloading the document content. The URL expires after 5 minutes.
Sourcepub fn document_content_length(&self) -> Option<i64>
pub fn document_content_length(&self) -> Option<i64>
The size of the document content in bytes available at the pre-signed URL.
Sourceimpl GetDocumentContentOutput
impl GetDocumentContentOutput
Sourcepub fn builder() -> GetDocumentContentOutputBuilder
pub fn builder() -> GetDocumentContentOutputBuilder
Creates a new builder-style object to manufacture GetDocumentContentOutput.