#[non_exhaustive]pub struct GetIngestedDocumentAclInputBuilder { /* private fields */ }Expand description
A builder for GetIngestedDocumentAclInput.
Implementations
Sourceimpl GetIngestedDocumentAclInputBuilder
impl GetIngestedDocumentAclInputBuilder
Sourcepub fn knowledge_base_id(self, input: impl Into<String>) -> Self
pub fn knowledge_base_id(self, input: impl Into<String>) -> Self
The unique identifier of the knowledge base that contains the document.
This field is required.Sourcepub fn set_knowledge_base_id(self, input: Option<String>) -> Self
pub fn set_knowledge_base_id(self, input: Option<String>) -> Self
The unique identifier of the knowledge base that contains the document.
Sourcepub fn get_knowledge_base_id(&self) -> &Option<String>
pub fn get_knowledge_base_id(&self) -> &Option<String>
The unique identifier of the knowledge base that contains the document.
Sourcepub fn data_source_id(self, input: impl Into<String>) -> Self
pub fn data_source_id(self, input: impl Into<String>) -> Self
The unique identifier of the data source that contains the document.
This field is required.Sourcepub fn set_data_source_id(self, input: Option<String>) -> Self
pub fn set_data_source_id(self, input: Option<String>) -> Self
The unique identifier of the data source that contains the document.
Sourcepub fn get_data_source_id(&self) -> &Option<String>
pub fn get_data_source_id(&self) -> &Option<String>
The unique identifier of the data source that contains the document.
Sourcepub fn document_id(self, input: impl Into<String>) -> Self
pub fn document_id(self, input: impl Into<String>) -> Self
The unique identifier of the document to retrieve the ingested access control list (ACL) for.
This field is required.Sourcepub fn set_document_id(self, input: Option<String>) -> Self
pub fn set_document_id(self, input: Option<String>) -> Self
The unique identifier of the document to retrieve the ingested access control list (ACL) for.
Sourcepub fn get_document_id(&self) -> &Option<String>
pub fn get_document_id(&self) -> &Option<String>
The unique identifier of the document to retrieve the ingested access control list (ACL) for.
Sourcepub fn build(self) -> Result<GetIngestedDocumentAclInput, BuildError>
pub fn build(self) -> Result<GetIngestedDocumentAclInput, BuildError>
Consumes the builder and constructs a GetIngestedDocumentAclInput.
Sourceimpl GetIngestedDocumentAclInputBuilder
impl GetIngestedDocumentAclInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GetIngestedDocumentAclOutput, SdkError<GetIngestedDocumentAclError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GetIngestedDocumentAclOutput, SdkError<GetIngestedDocumentAclError, HttpResponse>>
Sends a request with this input using the given client.