#[non_exhaustive]pub struct AgenticRetrieveGeneratedResponseBuilder { /* private fields */ }Expand description
A builder for AgenticRetrieveGeneratedResponse.
Implementations
Sourceimpl AgenticRetrieveGeneratedResponseBuilder
impl AgenticRetrieveGeneratedResponseBuilder
Sourcepub fn answer(self, input: impl Into<String>) -> Self
pub fn answer(self, input: impl Into<String>) -> Self
The generated answer text.
This field is required.Sourcepub fn set_answer(self, input: Option<String>) -> Self
pub fn set_answer(self, input: Option<String>) -> Self
The generated answer text.
Sourcepub fn get_answer(&self) -> &Option<String>
pub fn get_answer(&self) -> &Option<String>
The generated answer text.
Sourcepub fn citations(self, input: AgenticRetrieveCitation) -> Self
pub fn citations(self, input: AgenticRetrieveCitation) -> Self
Appends an item to citations.
To override the contents of this collection use set_citations.
Citations mapping spans of the answer to supporting results.
Sourcepub fn set_citations(self, input: Option<Vec<AgenticRetrieveCitation>>) -> Self
pub fn set_citations(self, input: Option<Vec<AgenticRetrieveCitation>>) -> Self
Citations mapping spans of the answer to supporting results.
Sourcepub fn get_citations(&self) -> &Option<Vec<AgenticRetrieveCitation>>
pub fn get_citations(&self) -> &Option<Vec<AgenticRetrieveCitation>>
Citations mapping spans of the answer to supporting results.
Sourcepub fn build(self) -> Result<AgenticRetrieveGeneratedResponse, BuildError>
pub fn build(self) -> Result<AgenticRetrieveGeneratedResponse, BuildError>
Consumes the builder and constructs a AgenticRetrieveGeneratedResponse.
This method will fail if any of the following fields are not set: