#[non_exhaustive]pub struct AgenticRetrieveResultEventBuilder { /* private fields */ }Expand description
A builder for AgenticRetrieveResultEvent.
Implementations
Sourceimpl AgenticRetrieveResultEventBuilder
impl AgenticRetrieveResultEventBuilder
Sourcepub fn results(self, input: AgenticRetrieveResultItem) -> Self
pub fn results(self, input: AgenticRetrieveResultItem) -> Self
Appends an item to results.
To override the contents of this collection use set_results.
The list of retrieved result items.
Sourcepub fn set_results(self, input: Option<Vec<AgenticRetrieveResultItem>>) -> Self
pub fn set_results(self, input: Option<Vec<AgenticRetrieveResultItem>>) -> Self
The list of retrieved result items.
Sourcepub fn get_results(&self) -> &Option<Vec<AgenticRetrieveResultItem>>
pub fn get_results(&self) -> &Option<Vec<AgenticRetrieveResultItem>>
The list of retrieved result items.
Sourcepub fn generated_response(self, input: AgenticRetrieveGeneratedResponse) -> Self
pub fn generated_response(self, input: AgenticRetrieveGeneratedResponse) -> Self
The generated response. Present only when generateResponse is true.
Sourcepub fn set_generated_response(
self,
input: Option<AgenticRetrieveGeneratedResponse>,
) -> Self
pub fn set_generated_response( self, input: Option<AgenticRetrieveGeneratedResponse>, ) -> Self
The generated response. Present only when generateResponse is true.
Sourcepub fn get_generated_response(
&self,
) -> &Option<AgenticRetrieveGeneratedResponse>
pub fn get_generated_response( &self, ) -> &Option<AgenticRetrieveGeneratedResponse>
The generated response. Present only when generateResponse is true.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
Opaque continuation token for paginated results.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
Opaque continuation token for paginated results.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
Opaque continuation token for paginated results.
Sourcepub fn build(self) -> Result<AgenticRetrieveResultEvent, BuildError>
pub fn build(self) -> Result<AgenticRetrieveResultEvent, BuildError>
Consumes the builder and constructs a AgenticRetrieveResultEvent.
This method will fail if any of the following fields are not set: