#[non_exhaustive]pub struct AgenticRetrieveTraceEventAttributesBuilder { /* private fields */ }Expand description
A builder for AgenticRetrieveTraceEventAttributes.
Implementations
Sourceimpl AgenticRetrieveTraceEventAttributesBuilder
impl AgenticRetrieveTraceEventAttributesBuilder
Sourcepub fn step(self, input: AgenticRetrieveStep) -> Self
pub fn step(self, input: AgenticRetrieveStep) -> Self
The current step in the retrieval process.
This field is required.Sourcepub fn set_step(self, input: Option<AgenticRetrieveStep>) -> Self
pub fn set_step(self, input: Option<AgenticRetrieveStep>) -> Self
The current step in the retrieval process.
Sourcepub fn get_step(&self) -> &Option<AgenticRetrieveStep>
pub fn get_step(&self) -> &Option<AgenticRetrieveStep>
The current step in the retrieval process.
Sourcepub fn status(self, input: AgenticRetrieveStatus) -> Self
pub fn status(self, input: AgenticRetrieveStatus) -> Self
The status of the current step.
This field is required.Sourcepub fn set_status(self, input: Option<AgenticRetrieveStatus>) -> Self
pub fn set_status(self, input: Option<AgenticRetrieveStatus>) -> Self
The status of the current step.
Sourcepub fn get_status(&self) -> &Option<AgenticRetrieveStatus>
pub fn get_status(&self) -> &Option<AgenticRetrieveStatus>
The status of the current step.
Sourcepub fn message(self, input: impl Into<String>) -> Self
pub fn message(self, input: impl Into<String>) -> Self
A human-readable message describing the trace event.
This field is required.Sourcepub fn set_message(self, input: Option<String>) -> Self
pub fn set_message(self, input: Option<String>) -> Self
A human-readable message describing the trace event.
Sourcepub fn get_message(&self) -> &Option<String>
pub fn get_message(&self) -> &Option<String>
A human-readable message describing the trace event.
Sourcepub fn actions(self, input: AgenticRetrieveAction) -> Self
pub fn actions(self, input: AgenticRetrieveAction) -> Self
Appends an item to actions.
To override the contents of this collection use set_actions.
The list of actions taken during this step.
Sourcepub fn set_actions(self, input: Option<Vec<AgenticRetrieveAction>>) -> Self
pub fn set_actions(self, input: Option<Vec<AgenticRetrieveAction>>) -> Self
The list of actions taken during this step.
Sourcepub fn get_actions(&self) -> &Option<Vec<AgenticRetrieveAction>>
pub fn get_actions(&self) -> &Option<Vec<AgenticRetrieveAction>>
The list of actions taken during this step.
Sourcepub fn warnings(self, input: AgenticRetrieveWarning) -> Self
pub fn warnings(self, input: AgenticRetrieveWarning) -> Self
Appends an item to warnings.
To override the contents of this collection use set_warnings.
Warnings generated during this step.
Sourcepub fn set_warnings(self, input: Option<Vec<AgenticRetrieveWarning>>) -> Self
pub fn set_warnings(self, input: Option<Vec<AgenticRetrieveWarning>>) -> Self
Warnings generated during this step.
Sourcepub fn get_warnings(&self) -> &Option<Vec<AgenticRetrieveWarning>>
pub fn get_warnings(&self) -> &Option<Vec<AgenticRetrieveWarning>>
Warnings generated during this step.
Sourcepub fn failures(self, input: AgenticRetrieveFailure) -> Self
pub fn failures(self, input: AgenticRetrieveFailure) -> Self
Appends an item to failures.
To override the contents of this collection use set_failures.
Failures that occurred during this step.
Sourcepub fn set_failures(self, input: Option<Vec<AgenticRetrieveFailure>>) -> Self
pub fn set_failures(self, input: Option<Vec<AgenticRetrieveFailure>>) -> Self
Failures that occurred during this step.
Sourcepub fn get_failures(&self) -> &Option<Vec<AgenticRetrieveFailure>>
pub fn get_failures(&self) -> &Option<Vec<AgenticRetrieveFailure>>
Failures that occurred during this step.
Sourcepub fn retrieval_metadata(self, input: AgenticRetrieveSourceMetadata) -> Self
pub fn retrieval_metadata(self, input: AgenticRetrieveSourceMetadata) -> Self
Appends an item to retrieval_metadata.
To override the contents of this collection use set_retrieval_metadata.
Metadata about the retrieval sources used.
Sourcepub fn set_retrieval_metadata(
self,
input: Option<Vec<AgenticRetrieveSourceMetadata>>,
) -> Self
pub fn set_retrieval_metadata( self, input: Option<Vec<AgenticRetrieveSourceMetadata>>, ) -> Self
Metadata about the retrieval sources used.
Sourcepub fn get_retrieval_metadata(
&self,
) -> &Option<Vec<AgenticRetrieveSourceMetadata>>
pub fn get_retrieval_metadata( &self, ) -> &Option<Vec<AgenticRetrieveSourceMetadata>>
Metadata about the retrieval sources used.
Sourcepub fn retrieval_response(self, input: AgenticRetrieveTraceResultItem) -> Self
pub fn retrieval_response(self, input: AgenticRetrieveTraceResultItem) -> Self
Appends an item to retrieval_response.
To override the contents of this collection use set_retrieval_response.
The retrieval results from this step.
Sourcepub fn set_retrieval_response(
self,
input: Option<Vec<AgenticRetrieveTraceResultItem>>,
) -> Self
pub fn set_retrieval_response( self, input: Option<Vec<AgenticRetrieveTraceResultItem>>, ) -> Self
The retrieval results from this step.
Sourcepub fn get_retrieval_response(
&self,
) -> &Option<Vec<AgenticRetrieveTraceResultItem>>
pub fn get_retrieval_response( &self, ) -> &Option<Vec<AgenticRetrieveTraceResultItem>>
The retrieval results from this step.
Sourcepub fn build(self) -> Result<AgenticRetrieveTraceEventAttributes, BuildError>
pub fn build(self) -> Result<AgenticRetrieveTraceEventAttributes, BuildError>
Consumes the builder and constructs a AgenticRetrieveTraceEventAttributes.
This method will fail if any of the following fields are not set: