#[non_exhaustive]pub struct ManagedSearchConfigurationBuilder { /* private fields */ }Expand description
A builder for ManagedSearchConfiguration.
Implementations
Sourceimpl ManagedSearchConfigurationBuilder
impl ManagedSearchConfigurationBuilder
Sourcepub fn number_of_results(self, input: i32) -> Self
pub fn number_of_results(self, input: i32) -> Self
The number of results to retrieve.
Sourcepub fn set_number_of_results(self, input: Option<i32>) -> Self
pub fn set_number_of_results(self, input: Option<i32>) -> Self
The number of results to retrieve.
Sourcepub fn get_number_of_results(&self) -> &Option<i32>
pub fn get_number_of_results(&self) -> &Option<i32>
The number of results to retrieve.
Sourcepub fn filter(self, input: RetrievalFilter) -> Self
pub fn filter(self, input: RetrievalFilter) -> Self
Specifies the filters to use on the metadata attributes in the knowledge base data sources before returning results. For more information, see Query configurations. See the examples below to see how to use these filters.
This data type is used in the following API operations:
-
Retrieve request – in the
filterfield -
RetrieveAndGenerate request – in the
filterfield
Sourcepub fn set_filter(self, input: Option<RetrievalFilter>) -> Self
pub fn set_filter(self, input: Option<RetrievalFilter>) -> Self
Specifies the filters to use on the metadata attributes in the knowledge base data sources before returning results. For more information, see Query configurations. See the examples below to see how to use these filters.
This data type is used in the following API operations:
-
Retrieve request – in the
filterfield -
RetrieveAndGenerate request – in the
filterfield
Sourcepub fn get_filter(&self) -> &Option<RetrievalFilter>
pub fn get_filter(&self) -> &Option<RetrievalFilter>
Specifies the filters to use on the metadata attributes in the knowledge base data sources before returning results. For more information, see Query configurations. See the examples below to see how to use these filters.
This data type is used in the following API operations:
-
Retrieve request – in the
filterfield -
RetrieveAndGenerate request – in the
filterfield
Sourcepub fn reranking_model_type(self, input: RerankingModelType) -> Self
pub fn reranking_model_type(self, input: RerankingModelType) -> Self
The type of reranking model to use when reranking results retrieved from the managed search. Use CUSTOM to specify a model, MANAGED to use the service default, or NONE to disable reranking.
Sourcepub fn set_reranking_model_type(self, input: Option<RerankingModelType>) -> Self
pub fn set_reranking_model_type(self, input: Option<RerankingModelType>) -> Self
The type of reranking model to use when reranking results retrieved from the managed search. Use CUSTOM to specify a model, MANAGED to use the service default, or NONE to disable reranking.
Sourcepub fn get_reranking_model_type(&self) -> &Option<RerankingModelType>
pub fn get_reranking_model_type(&self) -> &Option<RerankingModelType>
The type of reranking model to use when reranking results retrieved from the managed search. Use CUSTOM to specify a model, MANAGED to use the service default, or NONE to disable reranking.
Sourcepub fn reranking_configuration(
self,
input: ManagedSearchRerankingConfiguration,
) -> Self
pub fn reranking_configuration( self, input: ManagedSearchRerankingConfiguration, ) -> Self
Contains configurations for reranking the results retrieved from the managed search.
Sourcepub fn set_reranking_configuration(
self,
input: Option<ManagedSearchRerankingConfiguration>,
) -> Self
pub fn set_reranking_configuration( self, input: Option<ManagedSearchRerankingConfiguration>, ) -> Self
Contains configurations for reranking the results retrieved from the managed search.
Sourcepub fn get_reranking_configuration(
&self,
) -> &Option<ManagedSearchRerankingConfiguration>
pub fn get_reranking_configuration( &self, ) -> &Option<ManagedSearchRerankingConfiguration>
Contains configurations for reranking the results retrieved from the managed search.
Sourcepub fn build(self) -> ManagedSearchConfiguration
pub fn build(self) -> ManagedSearchConfiguration
Consumes the builder and constructs a ManagedSearchConfiguration.