#[non_exhaustive]pub enum AgenticRetrieveStreamResponseOutput {
ResponseEvent(AgenticRetrieveResponseEvent),
Result(AgenticRetrieveResultEvent),
TraceEvent(AgenticRetrieveTraceEvent),
#[non_exhaustive] Unknown,
}Expand description
The streaming output for agentic retrieval, containing results, traces, and errors.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ResponseEvent(AgenticRetrieveResponseEvent)
A chunk of the generated answer. Emitted only when generateResponse is true.
Result(AgenticRetrieveResultEvent)
A retrieval result event containing the retrieved items.
TraceEvent(AgenticRetrieveTraceEvent)
A trace event providing visibility into the retrieval process.
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl AgenticRetrieveStreamResponseOutput
impl AgenticRetrieveStreamResponseOutput
Sourcepub fn as_response_event(&self) -> Result<&AgenticRetrieveResponseEvent, &Self>
pub fn as_response_event(&self) -> Result<&AgenticRetrieveResponseEvent, &Self>
Tries to convert the enum instance into ResponseEvent, extracting the inner AgenticRetrieveResponseEvent.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_response_event(&self) -> bool
pub fn is_response_event(&self) -> bool
Returns true if this is a ResponseEvent.
Sourcepub fn as_result(&self) -> Result<&AgenticRetrieveResultEvent, &Self>
pub fn as_result(&self) -> Result<&AgenticRetrieveResultEvent, &Self>
Tries to convert the enum instance into Result, extracting the inner AgenticRetrieveResultEvent.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn as_trace_event(&self) -> Result<&AgenticRetrieveTraceEvent, &Self>
pub fn as_trace_event(&self) -> Result<&AgenticRetrieveTraceEvent, &Self>
Tries to convert the enum instance into TraceEvent, extracting the inner AgenticRetrieveTraceEvent.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_trace_event(&self) -> bool
pub fn is_trace_event(&self) -> bool
Returns true if this is a TraceEvent.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.