#[non_exhaustive]pub enum AgenticRetrieveWarning {
Guardrail(AgenticRetrieveGuardrailWarning),
Message(AgenticRetrieveWarningMessage),
#[non_exhaustive] Unknown,
}Expand description
A warning generated during agentic retrieval.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Guardrail(AgenticRetrieveGuardrailWarning)
A warning from a guardrail evaluation.
Message(AgenticRetrieveWarningMessage)
A general warning message.
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl AgenticRetrieveWarning
impl AgenticRetrieveWarning
Sourcepub fn as_guardrail(&self) -> Result<&AgenticRetrieveGuardrailWarning, &Self>
pub fn as_guardrail(&self) -> Result<&AgenticRetrieveGuardrailWarning, &Self>
Tries to convert the enum instance into Guardrail, extracting the inner AgenticRetrieveGuardrailWarning.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_guardrail(&self) -> bool
pub fn is_guardrail(&self) -> bool
Returns true if this is a Guardrail.
Sourcepub fn as_message(&self) -> Result<&AgenticRetrieveWarningMessage, &Self>
pub fn as_message(&self) -> Result<&AgenticRetrieveWarningMessage, &Self>
Tries to convert the enum instance into Message, extracting the inner AgenticRetrieveWarningMessage.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_message(&self) -> bool
pub fn is_message(&self) -> bool
Returns true if this is a Message.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.