#[non_exhaustive]pub struct AgenticRetrieveActionDetails {
pub input_query: Option<AgenticRetrieveMessageContent>,
pub source_retrievers: Vec<AgenticRetrieveSourceRetriever>,
}Expand description
Details of a retrieve action including the query and target retrievers.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.input_query: Option<AgenticRetrieveMessageContent>The input query used for retrieval.
source_retrievers: Vec<AgenticRetrieveSourceRetriever>The list of source retrievers targeted by this action.
Implementations
Sourceimpl AgenticRetrieveActionDetails
impl AgenticRetrieveActionDetails
Sourcepub fn input_query(&self) -> Option<&AgenticRetrieveMessageContent>
pub fn input_query(&self) -> Option<&AgenticRetrieveMessageContent>
The input query used for retrieval.
Sourcepub fn source_retrievers(&self) -> &[AgenticRetrieveSourceRetriever]
pub fn source_retrievers(&self) -> &[AgenticRetrieveSourceRetriever]
The list of source retrievers targeted by this action.
Sourceimpl AgenticRetrieveActionDetails
impl AgenticRetrieveActionDetails
Sourcepub fn builder() -> AgenticRetrieveActionDetailsBuilder
pub fn builder() -> AgenticRetrieveActionDetailsBuilder
Creates a new builder-style object to manufacture AgenticRetrieveActionDetails.