#[non_exhaustive]pub struct AgenticRetrieveGeneratedResponse {
pub answer: String,
pub citations: Option<Vec<AgenticRetrieveCitation>>,
}Expand description
The generated response synthesized from retrieved results.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.answer: StringThe generated answer text.
citations: Option<Vec<AgenticRetrieveCitation>>Citations mapping spans of the answer to supporting results.
Implementations
Sourceimpl AgenticRetrieveGeneratedResponse
impl AgenticRetrieveGeneratedResponse
Sourcepub fn citations(&self) -> &[AgenticRetrieveCitation]
pub fn citations(&self) -> &[AgenticRetrieveCitation]
Citations mapping spans of the answer to supporting results.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .citations.is_none().
Sourceimpl AgenticRetrieveGeneratedResponse
impl AgenticRetrieveGeneratedResponse
Sourcepub fn builder() -> AgenticRetrieveGeneratedResponseBuilder
pub fn builder() -> AgenticRetrieveGeneratedResponseBuilder
Creates a new builder-style object to manufacture AgenticRetrieveGeneratedResponse.