#[non_exhaustive]pub struct AgenticRetrieveTraceEventAttributes {
pub step: AgenticRetrieveStep,
pub status: AgenticRetrieveStatus,
pub message: String,
pub actions: Option<Vec<AgenticRetrieveAction>>,
pub warnings: Option<Vec<AgenticRetrieveWarning>>,
pub failures: Option<Vec<AgenticRetrieveFailure>>,
pub retrieval_metadata: Option<Vec<AgenticRetrieveSourceMetadata>>,
pub retrieval_response: Option<Vec<AgenticRetrieveTraceResultItem>>,
}Expand description
Attributes describing the details of an agentic retrieval trace event.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.step: AgenticRetrieveStepThe current step in the retrieval process.
status: AgenticRetrieveStatusThe status of the current step.
message: StringA human-readable message describing the trace event.
actions: Option<Vec<AgenticRetrieveAction>>The list of actions taken during this step.
warnings: Option<Vec<AgenticRetrieveWarning>>Warnings generated during this step.
failures: Option<Vec<AgenticRetrieveFailure>>Failures that occurred during this step.
retrieval_metadata: Option<Vec<AgenticRetrieveSourceMetadata>>Metadata about the retrieval sources used.
retrieval_response: Option<Vec<AgenticRetrieveTraceResultItem>>The retrieval results from this step.
Implementations
Sourceimpl AgenticRetrieveTraceEventAttributes
impl AgenticRetrieveTraceEventAttributes
Sourcepub fn step(&self) -> &AgenticRetrieveStep
pub fn step(&self) -> &AgenticRetrieveStep
The current step in the retrieval process.
Sourcepub fn status(&self) -> &AgenticRetrieveStatus
pub fn status(&self) -> &AgenticRetrieveStatus
The status of the current step.
Sourcepub fn actions(&self) -> &[AgenticRetrieveAction]
pub fn actions(&self) -> &[AgenticRetrieveAction]
The list of actions taken during this step.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .actions.is_none().
Sourcepub fn warnings(&self) -> &[AgenticRetrieveWarning]
pub fn warnings(&self) -> &[AgenticRetrieveWarning]
Warnings generated during this step.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .warnings.is_none().
Sourcepub fn failures(&self) -> &[AgenticRetrieveFailure]
pub fn failures(&self) -> &[AgenticRetrieveFailure]
Failures that occurred during this step.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .failures.is_none().
Sourcepub fn retrieval_metadata(&self) -> &[AgenticRetrieveSourceMetadata]
pub fn retrieval_metadata(&self) -> &[AgenticRetrieveSourceMetadata]
Metadata about the retrieval sources used.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .retrieval_metadata.is_none().
Sourcepub fn retrieval_response(&self) -> &[AgenticRetrieveTraceResultItem]
pub fn retrieval_response(&self) -> &[AgenticRetrieveTraceResultItem]
The retrieval results from this step.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .retrieval_response.is_none().
Sourceimpl AgenticRetrieveTraceEventAttributes
impl AgenticRetrieveTraceEventAttributes
Sourcepub fn builder() -> AgenticRetrieveTraceEventAttributesBuilder
pub fn builder() -> AgenticRetrieveTraceEventAttributesBuilder
Creates a new builder-style object to manufacture AgenticRetrieveTraceEventAttributes.