#[non_exhaustive]pub struct DocumentAclUser {
pub id: String,
pub type: DocumentAclMembershipType,
}Expand description
A user entry within a document access control list (ACL) condition.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringThe identifier of the user.
type: DocumentAclMembershipTypeThe membership type indicating the scope of the user entry.
Implementations
Sourceimpl DocumentAclUser
impl DocumentAclUser
Sourcepub fn builder() -> DocumentAclUserBuilder
pub fn builder() -> DocumentAclUserBuilder
Creates a new builder-style object to manufacture DocumentAclUser.