#[non_exhaustive]pub struct ManagedSearchConfiguration {
pub number_of_results: Option<i32>,
pub filter: Option<RetrievalFilter>,
pub reranking_model_type: Option<RerankingModelType>,
pub reranking_configuration: Option<ManagedSearchRerankingConfiguration>,
}Expand description
Configuration for managed search in a knowledge base. Managed search automatically determines the best search strategy based on your data store configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.number_of_results: Option<i32>The number of results to retrieve.
filter: Option<RetrievalFilter>Specifies the filters to use on the metadata attributes in the knowledge base data sources before returning results. For more information, see Query configurations. See the examples below to see how to use these filters.
This data type is used in the following API operations:
-
Retrieve request – in the
filterfield -
RetrieveAndGenerate request – in the
filterfield
reranking_model_type: Option<RerankingModelType>The type of reranking model to use when reranking results retrieved from the managed search. Use CUSTOM to specify a model, MANAGED to use the service default, or NONE to disable reranking.
reranking_configuration: Option<ManagedSearchRerankingConfiguration>Contains configurations for reranking the results retrieved from the managed search.
Implementations
Sourceimpl ManagedSearchConfiguration
impl ManagedSearchConfiguration
Sourcepub fn number_of_results(&self) -> Option<i32>
pub fn number_of_results(&self) -> Option<i32>
The number of results to retrieve.
Sourcepub fn filter(&self) -> Option<&RetrievalFilter>
pub fn filter(&self) -> Option<&RetrievalFilter>
Specifies the filters to use on the metadata attributes in the knowledge base data sources before returning results. For more information, see Query configurations. See the examples below to see how to use these filters.
This data type is used in the following API operations:
-
Retrieve request – in the
filterfield -
RetrieveAndGenerate request – in the
filterfield
Sourcepub fn reranking_model_type(&self) -> Option<&RerankingModelType>
pub fn reranking_model_type(&self) -> Option<&RerankingModelType>
The type of reranking model to use when reranking results retrieved from the managed search. Use CUSTOM to specify a model, MANAGED to use the service default, or NONE to disable reranking.
Sourcepub fn reranking_configuration(
&self,
) -> Option<&ManagedSearchRerankingConfiguration>
pub fn reranking_configuration( &self, ) -> Option<&ManagedSearchRerankingConfiguration>
Contains configurations for reranking the results retrieved from the managed search.
Sourceimpl ManagedSearchConfiguration
impl ManagedSearchConfiguration
Sourcepub fn builder() -> ManagedSearchConfigurationBuilder
pub fn builder() -> ManagedSearchConfigurationBuilder
Creates a new builder-style object to manufacture ManagedSearchConfiguration.